use maud::PreEscaped;

use crate::{
    templates,
    utils::{sbot, theme},
};

// ROUTE: /scuttlebutt/follows

/// Scuttlebutt follows list template builder.
pub fn build_template() -> PreEscaped<String> {
    // retrieve the list of follows
    match sbot::get_follows_list() {
        // populate the peers_list template with follows
        Ok(follows) => templates::peers_list::build_template(follows, "Follows"),
        Err(e) => {
            // render the sbot error template with the error message
            let error_template = templates::error::build_template(e.to_string());
            // wrap the nav bars around the error template content
            let body = templates::nav::build_template(error_template, "Follows", Some("/"));

            // query the current theme so we can pass it into the base template builder
            let theme = theme::get_theme();

            // render the base template with the provided body
            templates::base::build_template(body, theme)
        }
    }
}
